@@ -1,16 +1,16 @@
-# $Id: Tabs.pm,v 1.29 2003/01/26 17:30:51 koos Exp $
+# $Id: Tabs.pm,v 1.25 2002/11/23 09:52:48 koos Exp $
 
 package CGI::Widget::Tabs;
 
+use 5.006;
 use strict;
+use warnings;
 use Carp;
 use CGI::Widget::Tabs::Heading;
 use URI::Escape();
 use HTML::Entities();
 
-use vars qw/$VERSION/;
-
-$VERSION = '1.06.01';
+our $VERSION = '1.04';
 
 
 
@@ -21,7 +21,6 @@ sub new {
     my $class = ref($proto) || $proto;
     my $self = {};
     bless ($self, $class);
-    $self->indent(1);
     return $self;
 }
 
@@ -43,15 +42,29 @@ sub headings {
 
 
 
+
+# ----------------------------------------------
+sub _add_oo_heading {
+# ----------------------------------------------
+    my $self = shift;
+    if ( @_ ) {
+        push @{ $self->{headings} }, shift;
+    }
+    return @{ $self->{headings} || [] };
+}
+
+
+
+
 # ----------------------------------------------
 sub heading {
 # ----------------------------------------------
     #
-    # Create, add, and return a new heading object
+    # Create and return a new heading object
     #
     my $self = shift;
-    my $heading = CGI::Widget::Tabs::Heading->new;
-    push @{ $self->{headings} }, $heading;
+    my $heading = CGI::Widget::Tabs::Heading->new();
+    $self->_add_oo_heading($heading);
     return $heading;
 }
 
@@ -61,7 +74,7 @@ sub heading {
 sub default {
 # ----------------------------------------------
     #
-    # The default active heading
+    # The default active tab
     #
     my $self = shift;
     if ( @_ ) {
@@ -88,6 +101,7 @@ sub cgi_object {
         }
         $self->{cgi_object} = $cgi;
     }
+
     return $self->{cgi_object};
 }
 
@@ -120,7 +134,7 @@ sub active {
     #
     my $self = shift;
 
-    # 1. Heading clicked
+    # 1. Tab clicked
     my $clicked = $self->cgi_object->param($self->cgi_param);
     return $clicked if defined $clicked;  # that was easy :-)
 
@@ -135,7 +149,7 @@ sub active {
     return $self->default if defined $self->default;  # that was again very easy
     # 3. First
     my $first_heading = ($self->headings)[0];
-    return $first_heading->key || $first_heading->text;
+    return $first_heading->key || $first_heading->raw_text || $first_heading->text;
 }
 
 
@@ -156,38 +170,6 @@ sub class {
 
 
 
-# ----------------------------------------------
-sub wrap {
-# ----------------------------------------------
-    #
-    # wrap to next row after this num of headings
-    #
-    my $self = shift;
-    if ( @_ ) {
-        $self->{wrap} = shift;
-    }
-    return $self->{wrap};
-}
-
-
-
-# ----------------------------------------------
-sub indent {
-# ----------------------------------------------
-    #
-    # Indentation after wrapping to next line?
-    #
-    my $self = shift;
-    my $arg = shift;
-
-    if ( defined $arg ) {
-        $self->{indent} =  $arg ? 1 : 0;
-    }
-    return $self->{indent};
-}
-
-
-
 # ----------------------------------------------
 sub display {
 # ----------------------------------------------
@@ -212,166 +194,68 @@ sub render {
     my $class       = $self->class;
     my $cgi_param   = $self->cgi_param;
     my $active      = $self->active;
-    my $wrap        = $self->wrap;
-    my $indent      = $self->indent;
-    my $spacer      = '<td class="'.$class.'_spc"><img height="1" width="1"></td>';  # dummy image
-    my $indentation = '<td class="'.$class.'_ind"><img height="1" width="1"></td>'."\n";  # dummy image
+    my $spacer      = '<td class="'.$class.'_spc"><img height="1" width="1"></td>';
     my @html;
+    my $all_query_params_but_one = _all_query_params_but_one($cgi, $cgi_param);
     my $url;
-    my $query_string_min_min;  # the query string minus the varying tab
-
-    # - reproduce the CGI query string EXCEPT the varying tab
-    my @param_list = grep( $_ ne $cgi_param,$cgi->param() );
-    if ( @param_list ) {
-        $query_string_min_min = join "&", map ( "$_=".URI::Escape::uri_escape($cgi->param($_)||"") ,  @param_list );
-        $query_string_min_min .= "&";
-    } else {
-        $query_string_min_min = "";
-    }
 
+    @html = ();
+    push @html, "<!-- Generated by CGI::Widget::Tabs v$VERSION -->\n";
+    push @html, '<table class="',$class,'">',"\n<tr>\n";
+    push @html, $spacer,"\n";
 
     if ( @headings ) {
-
-        @html = ();
-        push @html, "<!-- Generated by CGI::Widget::Tabs v$VERSION -->\n";
-
-        # --- OO headings
-        if ( ref($headings[0] ) ) {
-            my $heading_nr = 1;  # first heading
-            my $row_nr     = 1;  # first row
+        # --- Are we dealing with the OO version of the headings,
+        # --- or is it a simple list (strings or k/v pairs) ?
+        if ( ref($headings[0] ) ) {  # it's a ref -> OO version
             my $param_value;
-
             foreach my $heading ( @headings ) {
-                if ( $heading_nr == 1 ) {   # first one in the row?
-                    push @html, _start_of_row($class, $spacer, $indent, $row_nr, $indentation);
-                }
-
-                # -- actual headings
-                $param_value = $heading->key || $heading->text;
+                $param_value = $heading->key || $heading->raw_text || $heading->text;
                 push @html, '<td class="',$class;
                 push @html, '_actv' if $param_value eq $active;
                 push @html, '">';
-                # cooked default URL or default self ref.
-                my $url = $heading->url || ( "?$query_string_min_min$cgi_param=".URI::Escape::uri_escape($param_value) );
-                push @html, _link( $heading->text , $url );
+                my $url = $heading->url || ( '?'.$all_query_params_but_one.$cgi_param.'='.URI::Escape::uri_escape($param_value) );
+                push @html, &_link( ( $heading->raw_text || HTML::Entities::encode_entities($heading->text) ) , $url );
                 push @html, "</td>";
                 push @html, $spacer,"\n";
-                # -- end of row
-                if ( $wrap && ( $heading_nr == $wrap ) ) {  # last one on the line?
-                    push @html,  "</tr>\n";     # | yes, end this row
-                    push @html,  "</table>\n";  # |
-                    $heading_nr = 0;
-                    $row_nr++;
-                }
-                $heading_nr++;
             }
 
-            # --- all headings printed
-            if ( $heading_nr != 1 )  {     # | Did we just get wrapped to
-                push @html, "</tr>\n";     # | the next line? In that case
-                push @html, "</table>\n";  # | we don't need an end-of-row.
-            }
-        }
-
-        # --- simple list headings
-        else {  # the first element is a scalar -> ("Heading") or ( -h => "Heading" );
-            # --- Did we get the -h => "Heading" version?
+        } else {  # the first element is a scalar -> ("Tab 1") or ( -t1 => "Tab1" );
+            # --- Did we get the -t=>"Tab" version?
             if ( substr($headings[0],0,1) eq '-' ) {
-                my $heading_nr = 1;  # first heading
-                my $row_nr     = 1;  # first row
                 my $heading_key;
                 my $heading_text;
                 while ( @headings ) {
-
-                    if ( $heading_nr == 1 ) {   # first one in the row?
-                        push @html, _start_of_row($class, $spacer, $indent, $row_nr, $indentation);
-                    }
-
-                    # -- actual headings
                     $heading_key  = shift @headings;
                     $heading_text = shift @headings;
                     push @html, '<td class="',$class;
                     push @html, '_actv' if $heading_key eq $active;
                     push @html, '">';
-                    push @html, _link($heading_text,"?$query_string_min_min$cgi_param=".URI::Escape::uri_escape($heading_key));
+                    push @html, &_link($heading_text,'?'.$all_query_params_but_one.$cgi_param.'='.URI::Escape::uri_escape($heading_key));
                     push @html, "</td>";
                     push @html, $spacer,"\n";
-
-                    # -- end of row
-                    if ( $wrap && ( $heading_nr == $wrap ) ) {  # last one on this row?
-                        push @html,  "</tr>\n";     # | yes, end this row
-                        push @html,  "</table>\n";  # |
-                        $heading_nr = 0;
-                        $row_nr++;
-                    }
-                    $heading_nr++;
                 }
-
-                # --- all headings printed
-                if ( $heading_nr != 1 )  {     # | Did we just get wrapped to
-                    push @html, "</tr>\n";     # | the next row? In that case
-                    push @html, "</table>\n";  # | we don't need an end-of-row.
-                }
-
             } else {
-                # --- No, we got the ("Heading1", "Heading2", ...)  version.
-                my $heading_nr = 1;  # first heading
-                my $row_nr     = 1;  # first row
+                # --- No, we got the ("Tab1", "Tab2", ...)  version.
                 foreach my $heading ( @headings ) {
-
-                    if ( $heading_nr == 1 ) {   # first one in the row?
-                        push @html, _start_of_row( $class, $spacer, $indent, $row_nr, $indentation );
-                    }
-
-                    # -- actual headings
                     push @html, '<td class="',$class;
                     push @html, '_actv' if $heading eq $active;
                     push @html, '">';
-                    push @html, _link($heading,"?$query_string_min_min$cgi_param=".URI::Escape::uri_escape($heading));
+                    push @html, &_link($heading,'?'.$all_query_params_but_one.$cgi_param.'='.URI::Escape::uri_escape($heading));
                     push @html, "</td>";
                     push @html, $spacer,"\n";
-
-                    # -- end of row
-                    if ( $wrap && ( $heading_nr == $wrap ) ) {  # last one on the row?
-                        push @html,  "</tr>\n";     # | yes, end this row
-                        push @html,  "</table>\n";  # |
-                        $heading_nr = 0;
-                        $row_nr++;
-                    }
-                    $heading_nr++;
-                }
-
-                # --- all headings printed
-                if ( $heading_nr != 1 )  {     # | Did we just get wrapped to
-                    push @html, "</tr>\n";     # | the next row? In that case
-                    push @html, "</table>\n";  # | we don't need an end-of-row.
                 }
             }
         }
     }
 
+    push @html, "</tr>\n</table>\n";
     push @html, "<!-- End CGI::Widget::Tabs v$VERSION -->\n";
     return join("",@html);
 }
 
 
 
-# ----------------------------------------------
-sub _start_of_row {
-# ----------------------------------------------
-    my ( $class, $spacer, $indent, $row_nr, $indentation ) = @_;
-    my @html = ();
-    push @html, "<table class=\"",$class,'">',"\n";
-    push @html,  "<tr>\n";
-    if ( $indent && $row_nr > 1 ) {                     # = print indents if
-        push @html, ( $indentation x ($row_nr - 1));    # = necessary
-    }                                                   # =
-    push @html, $spacer,"\n";                           # each row starts with a spacer
-    return @html;
-}
-
-
-
 # ----------------------------------------------
 sub _link {
 # ----------------------------------------------
@@ -384,13 +268,24 @@ sub _link {
 
 
 
+# ----------------------------------------------
+sub _all_query_params_but_one {
+# ----------------------------------------------
+    # reproduce the URL incl all CGI params, _except_ the varying tab
+    my ( $cgi, $cgi_param ) = @_;
+
+    my $all_query_params_but_one = "";
+    foreach ( $cgi->param() ) {
+        next if $_ eq $cgi_param;
+        $all_query_params_but_one .= $_.'='.URI::Escape::uri_escape($cgi->param($_)||"").'&';
+    }
+    return $all_query_params_but_one;
+}
+
+
 1;
-
 __END__
 
-
-
-
 =head1 NAME
 
 CGI::Widget::Tabs - Create tab widgets in HTML
@@ -409,15 +304,12 @@ CGI::Widget::Tabs - Create tab widgets in HTML
     $tab->class("my_tab");       # the CSS class to use for markup
     $tab->cgi_object($cgi);      # the object holding the query params
     $tab->cgi_param("t");        # the CGI query parameter to use
-    $tab->wrap(4);               # wrap after 4 headings...
-    $tab->indent(1);             # ...and add indentation
     $tab->render;                # the resulting HTML code
     $tab->display;               # same as `print $tab->render'
 
-
     $h = $tab->heading;               # new OO heading for this tab
-    $h->text("TV Listings");          # heading text
-    $h->raw(1);                       # switch off HTML encoding
+    $h->text("TV Listings");          # heading text. HTML escaped
+    $h->raw_text("TV&nbsp;Listings"); # similar. Not HTML escaped
     $h->key("tv");                    # key identifying this heading
     $h->url("whatsontonight.com");    # redirect URL for this heading
 
@@ -435,27 +327,20 @@ reasons for taking this approach:
 1. For the end user not to be directed to YAL or YAP (yet another link / yet
 another page), but keep it all together: The single point of entry paradigm.
 
-2. As a consequence the end user deals with a more consistent and integrated
-GUI. This will give a better "situational awareness" within the application.
-
-3. For the Perl hacker to handle multiple related data sources within the
-same script environment.
+2. For the Perl hacker to generate and display multiple data sources within
+the same script environment.
 
 
 As an example the following tabs could be used on a web page for someone's
 spotting hobby:
 
-      __________      __________      __________
-     /  Planes  \    /  Trains  \    / Classics \
-------------------------------------------------------
-         _________
-        /  Bikes  \
-------------------------
+      ________      ________      _____________
+     / Planes \    / Trains \    / Automobiles \
+-----------------------------------------------------
 
-As you can see, the headings wrap at three and a small indentation is added
-to the start of the next row. The nice thing about CGI::Widget::Tabs is that
-the tabs know their internal state. So you can ask a tab for instance which
-heading has been clicked by the user. This way you get instant feedback.
+The nice thing about CGI::Widget::Tabs is that the tabs know their internal
+state. So you can ask a tab for instance which tab heading has been clicked
+by the user. This way you get instant feedback.
 
 =head2 "Hey Gorgeous!"
 
@@ -470,52 +355,42 @@ CGI::Widget::Tabs use that. See the class() method for how to do this.
 
 Tab headings are the things that identify a tab page. Observe the spotting
 example above. Here the different tab pages are identified by the strings
-"Planes", "Trains", "Classics" and "Bikes". They form the heading of each
-page. These tab headings come in two flavors: simple headings and object
-oriented (OO) headings. Simple headings are the most easy and convenient ones
-to use. For instance in the spotting example the four tabs headings are
+"Planes", "Trains", and "Automobiles". These tab headings come in two
+flavors: simple headings and object oriented (OO) headings. Simple headings
+are the most easy and convenient ones to use. For instance in the spotting
+example the three tabs headings "Planes", "Trains", and "Automobiles" are
 easily created by feeding these words as a list to a CGI::Widget::Tabs
-object. And then you are almost done: the headings can be displayed and each
-heading gets it's own self referencing URL. The corresponding statements are:
+object. And then you are almost done: the headings can be displayed, each
+heading gets it's own self referencing URL and the tab object knows if you
+clicked either one of them. The corresponding statement would be:
 
-    my $tab = CGI::Widget::Tabs->new;
-    $tab->headings( qw/Planes Trains Classics Bikes/ );
-    $tab->wrap(3);
+    $tab->headings("Planes", "Trains", "Automobiles");
 
-This fast and easy to use mechanism has it's downside nonetheless. For
-instance the URL is always a self referencing URL. Also future extensions
---like support for thumbnail images-- is almost impossible. To allow for this
-extensibility headings can be defined in OO fashion. The OO statements to
-produce the headings would be something like:
+assuming $tab is the CGI::Widget::Tabs object. This fast and easy to use
+mechanism has it's downside nonetheless. For instance the URL is always a
+self referencing URL. Also future extensions --like support for thumbnail
+images-- is almost impossible. To allow for this extensibility headings can
+be defined in OO fashion. The OO statements to produce the headings above
+could be something like:
 
-    my $tab = CGI::Widget::Tabs->new;
-    foreach $ht ( qw/Planes Trains Classics Bikes/ ) {
-        $h = $tab->heading();  # create and add a heading object
+    foreach $ht ( qw/Planes Trains Automobiles/ ) {
+        $h = $tab->heading();  # create/add a heading object
         $h->text($ht);         # display $ht as heading text
     }
-    $tab->wrap(3);
 
 
 Here the text() method makes the heading object display the text given by
 $ht. Look at the heading() method elsewhere in this document to see which
 other methods are available to define the properties and behaviour of OO
-headings. Did you see that in both accounts the indent() method was not used?
-That is because indentation is automatic. You get that for free. Actually,
-you must explicitely turn if off if you don't want it! Note that you can not
-mix simple headings with OO headings. If you already defined simple headings
-you can't go adding OO headings or vice versa. You need to stick with one
-type.
+headings. Note that you can not mix simple headings with OO headings. If you
+already defined simple headings you can't go adding OO headings or vice
+versa. You need to stick with one type.
 
 
 
 
 =head1 COMMON METHODS FOR TAB OBJECTS
 
-Common methods deal with tab objects in general. They describe or define the
-global widget properties and it's behaviour.
-
-
-
 =over 4
 
 =item B<new()>
@@ -541,8 +416,8 @@ Example:
 
 Note how it does not matter if you configured simple headings or OO headings.
 Whichever you have chosen, active() will return the proper value: a value
-from the headings() method if you have configured simple headings, or a value of
-one of the text() or key() methods if you have configured OO
+from the headings() method if you have configured simple headings or a value of
+one of the text(), raw_text() or key() methods if you have configured OO
 headings.
 
 
@@ -557,11 +432,9 @@ such an object handler must provide a param() method with corresponding
 behaviour as do CGI or CGI::Minimal. Note that currently only CGI and
 CGI::Minimal have been tested. Example:
 
-    # set
     my $cgi = CGI::Minimal->new;
     $tab->cgi_object($cgi);
 
-    # get
     my $cgi = $tab->cgi_object;
 
 
@@ -598,7 +471,7 @@ use "tab" by default causing conflicts. Example:
 
 Sets/retrieves the name of the CSS class used for the tabs markup. If the
 optional argument STRING is given the class is set, otherwise it is
-retrieved. In the accompanying style sheet, there are five class elements you
+retrieved. In the accompanying style sheet, there are four class elements you
 need to provide:
 
 =over 4
@@ -611,72 +484,23 @@ need to provide:
 
 =item 4. A td element for the spacers
 
-=item 5. A td element for the indentation (if needed)
-
 =back
 
-The class names of these elements are directly borrowed from the class()
-method. The td elements for the active tab, the spacers and the indentations
-are suffixed with "_actv", "_spc" and "_ind" respectively. For instance, if
-you'd run
+The class names of these elements are gotten from the class() method. The
+element for an active tab gets "_actv" added to the class name. The spacer
+element gets "_spc" added. For instance, if you'd run
 
     $tab->class("my_tab");
 
-then the elements look like:
+then the four elements look like:
 
     <table class="my_tab">    # the entire table
     <td class="my_tab">       # normal tab
     <td class="my_tab_actv">  # highlighted tab
     <td class="my_tab_spc">   # spacer
-    <td class="my_tab_ind">   # indentation
-
-If you don't wrap headings, then ofcourse you won't need to specify the
-indentation td's. By the way, the indentation will usually look most natural
-if it has the same width as the spacers or a multiple thereof. Look at the
-example in the EXAMPLE section to see how this all works out.
 
 
-
-=item B<wrap(NUMBER)>
-
-Sets or retrieves the wrap setting. Without arguments the current wrap
-setting is returned. If the argument NUMBER is given the headings will wrap
-to the next row after NUMBER headings. By default headings are not wrapped.
-
-
-
-=item B<indent(BOOLEAN)>
-
-Sets/retrieves the indentation setting. Without arguments the current setting
-is returned. indent() specifies if indentation should be added to the next
-row when the headings get wrapped. indent() is a toggle. By default indent() is
-set to TRUE. You must explicitaly switch off indentation for the desired
-effect. The optional argument BOOLEAN can be any argument evaluating to a
-logical value.
-
-The purpose of swithing off indentation is to simulate a vertical menu. In
-the spotting example, running
-
-    $tab->wrap(1);
-    $tab->indent(0);
-
-could result in something like:
-
-      __________
-     |  Planes  |
-    --------------
-      __________
-     |  Trains  |
-    --------------
-      __________
-     | Classics |
-    --------------
-      __________
-     |  Bikes   |
-    --------------
-
-
-You probably need to tweak your style sheet to have it look nicely.
+Look at the example in the EXAMPLE section to see how this works out.
 
 
 
@@ -711,11 +535,6 @@ document to see how you can influence the markup of the tab widget. Example:
 
 =head1 METHODS FOR SIMPLE HEADINGS
 
-These methods define the properties of simple headings. As the simple
-headings are indeed very simple the wording "methods" isn't really accurate:
-you only need one :-)
-
-
 =over 4
 
 =item B<headings(LIST)>
@@ -734,25 +553,25 @@ headings are set. You can specify LIST in two ways:
 
 The keyword/value list comes in handy if you don't want to check the value
 returned by active() against very long words. Moreover, if you change the tab
-headings (upper/lower case, typo's) but use the same keys you don't need to
-change your code. So it is less  error prone. As a pleasant side effect, the
-URL's get significantly shorter. Do notice that the keys want to be unique.
+headings (upper/lower case!) but use the same keys you don't need to change
+your code. So it is less  error prone. As a pleasant side effect, the URL's
+get significantly shorter. Do notice that the keys want to be unique.
 Example:
 
     # plain list
-    $tab->headings( qw/Hardware Software Mobiles/ );
+    $tab->headings( qw/Planes Trains Automobiles/ );
 
     # k/v list
-    $tab->headings( -h => "Hardware",
-                    -s => "Software",
-                    -m => "Mobiles" );
+    $tab->headings( -p => "Planes",
+                    -t => "Trains",
+                    -a => "Automobiles" );
 
     # what have we got sofar?
     my @h = $tab->headings;
 
 
 Keys in a k/v list are not at all magical. You can choose any string you like
-with the provision that it starts with the '-' (hyphen) sign. The starting '-'
+with the provision that it starts with the '-' (minus) sign. The starting '-'
 of the list entries are what triggers CGI::Widget::Tabs to decide this list
 is a k/v list. So don't go and use plain list entries with a starting '-'.
 That won't work.
@@ -764,9 +583,6 @@ That won't work.
 
 =head1 METHODS FOR OO HEADINGS
 
-These methods define the properties and behaviour of the object oriented
-headings. Each OO heading can be tailored to specific requirements.
-
 =over 4
 
 =item B<heading()>
@@ -786,43 +602,31 @@ methods:
 =item B<text(STRING)>
 
 Sets/retrieves the heading text for the OO heading. If the optional argument
-STRING is given, the text will be set otherwise it will be retrieved. The
-heading text will be HTML encoded unless explicitely told otherwise (see: raw()).
-Examples:
+STRING is given, the text will be set otherwise it will be retrieved.
+On actual display STRING will be HTML escaped. Example:
 
     # set heading text
     $h1->text("Names A > L");
     $h2->text("Names M < Z");
 
-    # get the text of the 4th heading
+    # text of the 4th heading
     my $text = ($tab->headings)[3]->text;
 
 
 
-=item B<raw(BOOLEAN)>
+=item B<raw_text(STRING)>
 
-The heading text will normally be HTML encoded. You can pass those funny
-characters and the heading object will make sure it is displayed properly by
-encoding them into HTML. If you wish you can pass hardcoded HTML. To avoid
-escaping this HTML, you need to set raw() to a logical TRUE. This
-is usually a 1 (one). Setting it to FALSE (usually a 0) will re-enable HTML
-encoding. The optional argument BOOLEAN can be any argument evaluating to a
-logical value. Examples:
+Sets/retrieves the heading text for the OO heading. If the optionals argument
+STRING is given, the text will be set otherwise it will be retrieved. On
+actual display STRING will not be HTML escaped but passed as is. This is
+useful if you have some HTML preformatted text to display. Example:
 
-    # HTML encoded
-    $h1->text("Names A > L");
-    $h2->text("Names M < Z");
-
-    # Raw
-    $h1->text("Names A &gt; L");
-    $h1->raw(1);
-
-    $h2->text("Names M &lt; Z");
-    $h2->raw(1);
-
-    # get the encoding setting of the fourth element
-    my $raw = ($tab->headings)[3]->raw;
+    # set heading text
+    $h1->raw_text("Names&nbsp;A&nbsp;&gt;&nbsp;L");
+    $h2->raw_text("Names&nbsp;M&nbsp;&lt;&nbsp;Z");
 
+    # text of the 4th heading
+    my $text = ($tab->headings)[3]->text;
 
 
 =item B<key(STRING)>
@@ -892,7 +696,7 @@ simple headings. Copy it and run it through the webservers CGI engine. (For a
 even more complete and useful demo with multiple tabs, see the file
 tabs-demo.pl in the CGI::Widget::Tabs installation directory.)
 
-    # !/usr/bin/perl -w
+    #!/usr/bin/perl -w
 
     use CGI::Widget::Tabs;
     use CGI;
@@ -902,11 +706,10 @@ tabs-demo.pl in the CGI::Widget::Tabs installation directory.)
 
     <head>
     <style type="text/css">
-    table.my_tab   { border-bottom: solid thin black; text-align: center }
-    td.my_tab      { padding: 2 12 2 12; width: 80; background-color: #FAFAD2 }
-    td.my_tab_actv { padding: 2 12 2 12; width: 80; background-color: #C0D4E6 }
-    td.my_tab_spc  { width: 5 }
-    td.my_tab_ind  { width: 15 }
+    table.my_tab   { border-bottom: solid thin black }
+    td.my_tab      { padding: 2 12 2 12; background-color: #FAFAD2 }
+    td.my_tab_actv { padding: 2 12 2 12; background-color: #C0D4E6 }
+    td.my_tab_spc  { width: 15 }
     </style></head>
     <body>
     EOT
@@ -915,11 +718,8 @@ tabs-demo.pl in the CGI::Widget::Tabs installation directory.)
     my $tab = CGI::Widget::Tabs->new;
     $tab->cgi_object($cgi);
     $tab->class("my_tab");
-    $tab->headings( "Hardware", "Software", "Lease Cars", "Xerox", "Mobiles");
-    $tab->wrap(3);
-    # $tab->wrap(1);    # |uncomment to see the effect of
-    # $tab->indent(0);  # |wrapping at 1 without indentation
-    $tab->default("Software");
+    $tab->headings( "Hardware", "Lease Cars", "Xerox", "Mobiles");
+    $tab->default("Lease Cars");
     $tab->display;
     print "<br>We now should run some intelligent code ";
     print "to process <strong>", $tab->active, "</strong><br>";
@@ -945,7 +745,7 @@ release.
 
 
 
-=head1 ACKNOWLEDGEMENTS
+=head1 CREDITS
 
 =over 4
 
